"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const request = require("request-promise-native");
// import chalk from 'chalk';
class AnalyticsAppShare extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        const defaultRequest = {
            json: true,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            }
        };
        const folders = await request(Object.assign({}, defaultRequest, { uri: `${conn.instanceUrl}/services/data/v45.0/wave/folders` }));
        // this.ux.logJson(folders);
        // match the folder from the list
        const foundFolder = folders.folders.find(folder => folder.name === this.flags.name);
        // this.ux.logJson(foundFolder);
        if (!foundFolder) {
            throw new Error(`no application by that name exists.  Folders: ${folders.folders.map(folder => folder.name).join(',')}`);
        }
        // get the applications's existing json > shares
        const retrievedFolder = await request(Object.assign({}, defaultRequest, { uri: `${conn.instanceUrl}/services/data/v45.0/wave/folders/${foundFolder.id}` }));
        // convert shareRepresentation to shareInputRepresentation
        let sharesToPatch = retrievedFolder.shares.map(share => {
            delete share.sharedWithLabel;
            delete share.imageUrl;
            return share;
        });
        if (this.flags.allprm) {
            sharesToPatch = [...sharesToPatch, { shareType: 'allprmusers', accessType: this.flags.type }];
        }
        // doesn't seem to work correctly, but might be my org not having csp users on?
        if (this.flags.allcsp) {
            sharesToPatch = [...sharesToPatch, { shareType: 'allcspusers', accessType: this.flags.type }];
        }
        if (this.flags.org) {
            sharesToPatch = [...sharesToPatch, { shareType: 'organization', accessType: this.flags.type }];
        }
        // this.ux.logJson(sharesToPatch);
        const patchResult = await request(Object.assign({}, defaultRequest, { method: 'PATCH', body: { shares: sharesToPatch }, uri: `${conn.instanceUrl}/services/data/v45.0/wave/folders/${foundFolder.id}` }));
        if (!this.flags.json) {
            this.ux.logJson(patchResult);
        }
        // do we need to make it shared with communities?
        if ((this.flags.allcsp || this.flags.allprm) && !retrievedFolder.canBeSharedExternally) {
            const communityShareResult = await request(Object.assign({}, defaultRequest, { uri: `${conn.instanceUrl}/services/data/v45.0/wave/folders/${foundFolder.id}`, method: 'PATCH', body: { canBeSharedExternally: true } }));
            if (!this.flags.json) {
                this.ux.logJson(communityShareResult);
            }
        }
        return patchResult;
    }
}
AnalyticsAppShare.description = 'share an analytics app by name';
AnalyticsAppShare.examples = [
    `sfdx shane:analytics:app:share -n SharedApp --allprm -c
// share the standard SharedApp with all partners view level perms (default) and check the "enable sharing with communities" box for this app
`
];
AnalyticsAppShare.flagsConfig = {
    name: command_1.flags.string({ char: 'n', required: true, description: 'name of the analytics app' }),
    allprm: command_1.flags.boolean({ description: 'share with all partner users', dependsOn: ['community'] }),
    allcsp: command_1.flags.boolean({ description: 'share with all customer portal users', dependsOn: ['community'] }),
    org: command_1.flags.boolean({ description: 'share with all internal users' }),
    community: command_1.flags.boolean({ char: 'c', description: 'enable community sharing' }),
    type: command_1.flags.string({ char: 't', default: 'View', description: 'access level', options: ['View', 'Edit', 'Manage'] })
};
// Comment this out if your command does not require an org username
AnalyticsAppShare.requiresUsername = true;
exports.default = AnalyticsAppShare;
//# sourceMappingURL=share.js.map