"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const child_process = require("child_process");
const puppeteer = require("puppeteer");
const stripcolor = require("strip-color");
const util = require("util");
// import { Record } from './../../../shared/typeDefs';
const exec = util.promisify(child_process.exec);
class CommunityEnable extends command_1.SfdxCommand {
    async run() {
        // this.ux.startSpinner('starting headless browser');
        const browser = await puppeteer.launch({ headless: !this.flags.showbrowser, args: ['--no-sandbox'] });
        const context = browser.defaultBrowserContext();
        // // get the force-org-open url for your scratch org
        const openResult = await exec('sfdx force:org:open -p /lightning/setup/InsightsSetupSettings/home -r --json');
        const iframeTitle = 'Get Started ~ Salesforce - Developer Edition';
        const url = JSON.parse(stripcolor(openResult.stdout)).result.url;
        await context.overridePermissions(url, ['notifications']);
        const page = await browser.newPage();
        await page.goto(url, {
            waitUntil: 'networkidle2'
        });
        const enable = 'input.enableWaveInCommunities';
        await page.waitForSelector(`iframe[title="${iframeTitle}"]`);
        for (const frame of page.frames()) {
            const title = await frame.title();
            if (title === iframeTitle) {
                await frame.waitForSelector('input.enableWaveInCommunities');
                await frame.click(enable);
                // verify that it actually changed value from the click?
                await frame.waitForSelector('input.enableWaveInCommunities:checked');
                await frame.waitForSelector('input[title="Save"]');
                await frame.click('input[title="Save"]');
                // this.ux.log('clicked save');
                await frame.waitFor(500);
                await browser.close();
                // this.ux.stopSpinner('Activated analytics for communities');
                return true;
            }
        }
        await browser.close();
        throw new Error('UI elements not found');
    }
}
CommunityEnable.description = 'Activate a community using a headless browser';
CommunityEnable.aliases = ['shane:communities:analytics:enable'];
CommunityEnable.requiresUsername = true;
CommunityEnable.flagsConfig = {
    showbrowser: command_1.flags.boolean({ char: 'b', description: 'show the browser...useful for local debugging' })
};
exports.default = CommunityEnable;
//# sourceMappingURL=enable.js.map