"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const kit_1 = require("@salesforce/kit");
const fs = require("fs-extra");
const writeJSONOptions = {
    spaces: 2
};
class CDCStream extends command_1.SfdxCommand {
    async run() {
        const streamProcessor = message => {
            this.ux.logJson(message);
            return { completed: false };
        };
        const streamProcessorToFile = (message) => {
            const filename = `${this.flags.dir}/cdc/records/${message.payload.ChangeEventHeader.entityName}/${message.event.replayId}.json`;
            fs.outputJSON(filename, message, writeJSONOptions);
            return { completed: false };
        };
        const endpoint = this.flags.object ? `/data/${this.flags.object.replace('__c', '__')}ChangeEvent` : '/data/ChangeEvents';
        // create a client
        const options = new core_1.StreamingClient.DefaultOptions(this.org, endpoint, this.flags.dir ? streamProcessorToFile : streamProcessor);
        options.apiVersion = await this.org.retrieveMaxApiVersion();
        options.subscribeTimeout = new kit_1.Duration(60 * 100);
        const client = await core_1.StreamingClient.create(options);
        await client.handshake();
        await client.subscribe(async () => {
            this.ux.log(`Listening on ${endpoint}... (ctrl-c to exit)`);
        });
    }
}
CDCStream.examples = [
    'sfdx shane:cdc:stream // get all the change events',
    'sfdx shane:cdc:stream -o Account // get all the change events on a single object',
    'sfdx shane:cdc:stream -d myDir // stream change events to myDir/cdc, organized into folders by object api type'
];
CDCStream.flagsConfig = {
    object: command_1.flags.string({ char: 'o', description: 'subscribe to change events for only a single object (api name, including __c)' }),
    dir: command_1.flags.directory({ char: 'd', description: 'stream the events to a folder instead of the console' })
};
CDCStream.requiresUsername = true;
exports.default = CDCStream;
//# sourceMappingURL=stream.js.map