"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const jsToXml = require("js2xmlparser");
const getExisting_1 = require("./../../../shared/getExisting");
const options = require("../../../shared/js2xmlStandardOptions");
const chalk_1 = require("chalk");
class ConnectedAppUniquify extends command_1.SfdxCommand {
    async run() {
        const exists = await fs.pathExists(this.flags.app);
        if (!exists) {
            throw new Error(`file not found: ${this.flags.app}`);
        }
        const consumerKey = `${this.flags.prefix}x${new Date().getTime()}`;
        const existing = await getExisting_1.getExisting(this.flags.app, 'ConnectedApp');
        existing.oauthConfig.consumerKey = consumerKey;
        const output = await getExisting_1.fixExistingDollarSign(existing);
        const xml = jsToXml.parse('ConnectedApp', output, options.js2xmlStandardOptions);
        fs.writeFileSync(this.flags.app, xml);
        this.ux.log(`${chalk_1.default.green('Connected app updated locally')}.  Consumer Key is now ${consumerKey}`);
    }
}
ConnectedAppUniquify.description = 'modify a clientId/consumerKey on a local connected app to guaranatee uniqueness';
ConnectedAppUniquify.examples = [
    `sfdx shane:connectedapp:uniquify -a force-app/main/default/connectedappmyConnectedApp -p 5h4n3
// update the consumerKey of myConnectedApp to be unique, but start with 5h4n3
`
];
ConnectedAppUniquify.flagsConfig = {
    prefix: command_1.flags.string({ char: 'p', required: true, description: 'add a prefix to the connected app\'s consumerKey' }),
    app: command_1.flags.filepath({ char: 'a', required: true, description: 'full path to your connected app locally' })
};
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
ConnectedAppUniquify.requiresProject = true;
exports.default = ConnectedAppUniquify;
//# sourceMappingURL=uniquify.js.map