"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
class IdQuery extends command_1.SfdxCommand {
    async run() {
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        const query = `select id from ${this.flags.object} where ${this.flags.where}`;
        const results = await conn.query(query);
        if (results.records.length > 1) {
            throw new Error('There are more than 1 matching records');
        }
        else if (results.records.length === 0) {
            throw new Error('No records found');
        }
        else {
            // tslint:disable-next-line:no-any
            this.ux.log(results.records[0].Id);
            return results.records[0].Id;
        }
    }
}
IdQuery.description = 'query some object and get back the id of the matching record';
IdQuery.examples = [
    `sfdx shane:data:id:query -o User -u platformers -w "Firstname = 'Shane' and Lastname = 'McLaughlin' and username = 'shane@platformers.org'"'
    // returns the id of the user. Use these ids between \`\` in other commands
    `
];
IdQuery.flagsConfig = {
    object: command_1.flags.string({ char: 'o', description: 'object', required: true }),
    where: command_1.flags.string({ char: 'w', description: 'SOQL where clause for your query', required: true })
};
IdQuery.requiresUsername = true;
IdQuery.requiresProject = false;
exports.default = IdQuery;
//# sourceMappingURL=query.js.map