"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const child_process = require("child_process");
const request = require("request-promise-native");
const stripcolor = require("strip-color");
const util = require("util");
const exec = util.promisify(child_process.exec);
class GithubPackageInstall extends command_1.SfdxCommand {
    async run() {
        let packageVersionId;
        // first, look in the sfdx-project.json file, using the packaging output from v43
        let url = `https://raw.githubusercontent.com/${this.flags.githubuser}/${this.flags.repo}/master/sfdx-project.json`;
        const primaryResult = await request.get({
            url,
            json: true
        });
        // this.ux.log(`file at ${url} says:`);
        if (primaryResult.packageAliases) {
            // grab the last package version unless a version is specified
            const packages = Object.values(primaryResult.packageAliases);
            // this.ux.log(`packages are ${packages}`);
            packageVersionId = packages[packages.length - 1];
            if (packageVersionId.startsWith('04t')) {
                this.ux.log(`found packageVersionId ${packageVersionId} in the sfdx-project.json file`);
            }
            else {
                throw new Error('no package version id found');
            }
        }
        else {
            // try the fallback option
            // get the SubscriberPackageVersionId from github using Shane's original format
            url = `https://raw.githubusercontent.com/${this.flags.githubuser}/${this.flags.repo}/master/latestVersion.json`;
            // this.ux.log(`file at ${url} says:`);
            const result = await request.get({
                url,
                json: true
            });
            // this.ux.log(result);
            packageVersionId = result.SubscriberPackageVersionId;
            // install in the org
        }
        const installResult = await exec(`sfdx force:package:install --package ${packageVersionId} -r -u ${this.org.getUsername()} -w 20 --publishwait 20 --json`);
        // this.ux.logJson(JSON.parse(installResult.stdout));
        return JSON.parse(stripcolor(installResult.stdout));
    }
}
GithubPackageInstall.description = 'installs a package from github using the sfdx-project.json file (v43+) OR the latestVersion.json file convention';
GithubPackageInstall.examples = [
    `sfdx shane:github:package:install -g someUser -r someRepo -u someOrg
// installs packageVersion (04t) from https://github.com/someUser/someRepo/sfdx-project.json or https://github.com/someUser/someRepo/latestVersion.json
`
];
GithubPackageInstall.requiresUsername = true;
GithubPackageInstall.flagsConfig = {
    githubuser: command_1.flags.string({ required: true, char: 'g', description: 'github username where the package lives' }),
    repo: command_1.flags.string({ required: true, char: 'r', description: 'repo where the packages lives' })
    // branch: { type: 'string',  char: 'b', description: 'optional branch' })
};
GithubPackageInstall.requiresProject = true;
exports.default = GithubPackageInstall;
//# sourceMappingURL=install.js.map