"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const util = require("util");
const child_process = require("child_process");
const exec = util.promisify(child_process.exec);
class Push extends command_1.SfdxCommand {
    async run() {
        if (!fs.existsSync(this.flags.source)) {
            this.ux.error(`your source folder [${this.flags.source}] doesn't exist`);
        }
        fs.ensureDirSync(this.flags.convertedfolder);
        process.stdout.write('Starting source conversion');
        await exec(`sfdx force:source:convert -d ${this.flags.convertedfolder} -r ${this.flags.source}`);
        process.stdout.write('done.  Deploying...');
        await exec(`sfdx force:mdapi:deploy -w ${this.flags.deploymenttimelimit} -d ${this.flags.convertedfolder} -u ${this.org.getUsername()}`);
        if (!this.flags.keepconverted) {
            process.stdout.write('done.  Cleaning up...');
            await fs.remove(this.flags.convertedfolder);
        }
        process.stdout.write('Done!\n');
    }
}
Push.description = 'convert and deploy the packaged source';
Push.examples = [
    `sfdx shane:mdapi:push -u someOrg
// convert to mdapi format and push to the given org
`
];
Push.requiresUsername = true;
Push.flagsConfig = {
    convertedfolder: command_1.flags.directory({ char: 'd', description: 'where to store the mdapi-converted source', default: 'mdapiout' }),
    keepconverted: command_1.flags.boolean({ char: 'k', description: 'Don\'t automatically delete the converted source' }),
    source: command_1.flags.directory({ char: 'r', default: 'force-app', description: 'deploy a specific folder that\'s not force-app' }),
    deploymenttimelimit: command_1.flags.integer({ char: 'w', description: 'How many minutes to wait for the deployment to finish', default: 200 })
};
Push.requiresProject = true;
exports.default = Push;
//# sourceMappingURL=push.js.map