"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
class FieldDescribe extends command_1.SfdxCommand {
    async run() {
        const conn = await this.org.getConnection();
        const metadata = await conn.sobject(this.flags.object).describe();
        // this.ux.logJson(metadata.fields);
        const output = [];
        for (const field of metadata.fields) {
            const rewritten = {
                name: field.name,
                label: field.label,
                type: typeTransform(field),
                required: requiredTransform(field)
            };
            output.push(rewritten);
        }
        this.ux.table(output, ['name', 'label', 'required', 'type']);
        function typeTransform(field) {
            if (field.calculated) {
                return `formula/${field.type}`;
            }
            else if (field.type === 'double') {
                return `${field.type} (${field.precision}, ${field.scale})`;
            }
            else if (field.type === 'reference') {
                return `${field.type} (${field.referenceTo})`;
            }
            else if (field.type === 'picklist' || field.type === 'multipicklist ') {
                return `${field.type}(${field.picklistValues.map(pLV => pLV.value)})`;
            }
            else {
                return field.type;
            }
        }
        function requiredTransform(field) {
            if (field.type === 'boolean') {
                return false;
            }
            else {
                return !field.nillable;
            }
        }
    }
}
FieldDescribe.description = 'what fields are on the object?';
FieldDescribe.examples = [
    `sfdx shane:object:fields:describe -o Account -u someOrg
// list the fields (with type/label) on account
`
];
FieldDescribe.requiresUsername = true;
FieldDescribe.flagsConfig = {
    object: command_1.flags.string({ required: true, char: 'o', description: 'the object to describe' })
};
FieldDescribe.requiresProject = false;
exports.default = FieldDescribe;
//# sourceMappingURL=describe.js.map