"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const jsToXml = require("js2xmlparser");
const options = require("../../../shared/js2xmlStandardOptions");
class PowerOfOne extends command_1.SfdxCommand {
    async run() {
        if (this.flags.api.includes(' ')) {
            this.ux.error(chalk_1.default.red('spaces are not allowed in the api name'));
        }
        if (!this.flags.api.includes('__c')) {
            this.flags.api = `${this.flags.api}__c`;
        }
        // remove trailing slash if someone entered it
        if (this.flags.target.endsWith('/')) {
            this.flags.target = this.flags.target.substring(0, this.flags.target.length - 1);
        }
        fs.ensureDirSync(`${this.flags.target}/objects`);
        fs.ensureDirSync(`${this.flags.target}/objects/${this.flags.object}`);
        fs.ensureDirSync(`${this.flags.target}/objects/${this.flags.object}/fields`);
        const fieldJSON = {
            '@': {
                xmlns: 'http://soap.sforce.com/2006/04/metadata'
            },
            fullName: this.flags.api,
            externalId: false,
            formula: 1,
            formulaTreatBlanksAs: 'BlankAsZero',
            label: this.flags.label,
            precision: 18,
            required: false,
            scale: 0,
            type: 'Number',
            unique: false,
            description: this.flags.description
        };
        const xml = jsToXml.parse('CustomField', fieldJSON, options.js2xmlStandardOptions);
        fs.writeFileSync(`${this.flags.target}/objects/${this.flags.object}/fields/${this.flags.api}.field-meta.xml`, xml);
        this.ux.log(`${chalk_1.default.green('Power of One field created for you')}.  It's only local...push to deploy.`);
    }
}
PowerOfOne.description = 'add a "power of one" formula field to any object';
PowerOfOne.examples = [
    `sfdx shane:object:powerofone -a Poo -l "Power of One" -o User
// create a field with api name Poo__c and label "Power of One" on the user object with the default description in the default folder
`
];
PowerOfOne.flagsConfig = {
    object: command_1.flags.string({ char: 'o', required: true, description: 'API name of the object to add the field to' }),
    label: command_1.flags.string({ char: 'l', default: 'Power Of One', description: 'label' }),
    api: command_1.flags.string({ char: 'a', default: 'Power_Of_One__c', description: 'api name (will include the __c for you if you don\'t add it here' }),
    description: command_1.flags.string({ char: 'd', default: 'Power of one is used for formulas, reporting, etc', description: 'optional description so you can remember why you added this and what it\'s for' }),
    target: command_1.flags.directory({ char: 't', default: 'force-app/main/default', description: 'where to create the folder (if it doesn\'t exist already) and file...defaults to force-app/main/default' })
};
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
PowerOfOne.requiresProject = true;
exports.default = PowerOfOne;
//# sourceMappingURL=powerofone.js.map