"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const jsToXml = require("js2xmlparser");
const getExisting_1 = require("../../../shared/getExisting");
const setupArray_1 = require("../../../shared/setupArray");
const options = require("../../../shared/js2xmlStandardOptions");
class ProfileWhitelist extends command_1.SfdxCommand {
    async run() {
        fs.ensureDirSync(`${this.flags.directory}/profiles`); // create profiles locally if it doesn't exist already
        const targetProfile = `${this.flags.directory}/profiles/${this.flags.name}.profile-meta.xml`;
        let existing = await getExisting_1.getExisting(targetProfile, 'Profile', {
            '@': {
                xmlns: 'http://soap.sforce.com/2006/04/metadata'
            }
        });
        existing = setupArray_1.setupArray(existing, 'loginIpRanges');
        existing.loginIpRanges.push({
            description: 'the whole internet',
            startAddress: '0.0.0.0',
            endAddress: '255.255.255.255'
        });
        existing = await getExisting_1.fixExistingDollarSign(existing);
        // convert to xml and write out the file
        const xml = jsToXml.parse('Profile', existing, options.js2xmlStandardOptions);
        fs.writeFileSync(targetProfile, xml);
        this.ux.log(chalk_1.default.green(`Whitelisted ${targetProfile} locally`) + '...next, push or deploy to an org.');
        return existing; // for someone who wants the JSON?
    }
}
ProfileWhitelist.description = 'whitelist the whole internet for a profile (no ip verification or 2FA/OTP challenges in dev)';
ProfileWhitelist.examples = [
    `sfdx shane:profile:whitelist -n Admin
// add loginIpRanges of 0.0.0.0 to 255.255.255.255 to an existing profile, or create one if it doesn't exist
`
];
ProfileWhitelist.flagsConfig = {
    name: command_1.flags.string({ char: 'n', required: true, description: 'profile name' }),
    directory: command_1.flags.directory({ char: 'd', default: 'force-app/main/default', description: 'Where is all this metadata? defaults to force-app/main/default' })
};
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
ProfileWhitelist.requiresProject = true;
exports.default = ProfileWhitelist;
//# sourceMappingURL=whitelist.js.map