"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const jsToXml = require("js2xmlparser");
const options = require("../../../shared/js2xmlStandardOptions");
const chalk_1 = require("chalk");
class RemoteSite extends command_1.SfdxCommand {
    async run() {
        if (this.flags.name.includes(' ')) {
            this.ux.error(chalk_1.default.red('spaces are not allowed in the name'));
        }
        // remove trailing slash if someone entered it
        if (this.flags.target.endsWith('/')) {
            this.flags.target = this.flags.target.substring(0, this.flags.target.length - 1);
        }
        fs.ensureDirSync(`${this.flags.target}/remoteSiteSettings`);
        const settingJSON = {
            '@': {
                xmlns: 'http://soap.sforce.com/2006/04/metadata'
            },
            url: this.flags.url,
            disableProtocolSecurity: false,
            isActive: true,
            description: this.flags.description
        };
        const xml = jsToXml.parse('RemoteSiteSetting', settingJSON, options.js2xmlStandardOptions);
        fs.writeFileSync(`${this.flags.target}/remoteSiteSettings/${this.flags.name}.remoteSite-meta.xml`, xml);
        this.ux.log(chalk_1.default.green('Remote site created locally'));
    }
}
RemoteSite.description = 'create a remote site setting in the local source.  Push it when you\'re done';
RemoteSite.examples = [
    `sfdx shane:remotesite:create -n Test -u https://www.google.com
// create a remote site setting in force-app/main/default
`,
    `sfdx shane:remotesite:create -n Test -u https://www.google.com -d "my description" -t myOtherDirectory/main/default
// create a remote site setting in myOtherDirectory/main/default with a description
`
];
RemoteSite.flagsConfig = {
    url: command_1.flags.url({ char: 'u', required: true, description: 'url that you want to allow callouts to' }),
    name: command_1.flags.string({ char: 'n', required: true, description: 'name it (Salesforce API compliant name)' }),
    description: command_1.flags.string({ char: 'd', default: 'added from sfdx plugin', description: 'optional description so you can remember why you added this and what it\'s for' }),
    target: command_1.flags.directory({ char: 't', default: 'force-app/main/default', description: 'where to create the folder (if it doesn\'t exist already) and file...defaults to force-app/main/default' })
};
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
RemoteSite.requiresProject = true;
exports.default = RemoteSite;
//# sourceMappingURL=create.js.map