"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const child_process = require("child_process");
const puppeteer = require("puppeteer");
const stripcolor = require("strip-color");
const util = require("util");
const exec = util.promisify(child_process.exec);
class ThemeActivate extends command_1.SfdxCommand {
    async run() {
        // first, get the id of the theme
        const conn = this.org.getConnection();
        const results = await conn.query(`select id from LightningExperienceTheme where DeveloperName = '${this.flags.name}' or MasterLabel = '${this.flags.name}'`);
        if (results.records.length > 1) {
            throw new Error('There are more than 1 matching records');
        }
        else if (results.records.length === 0) {
            throw new Error('No records found');
        }
        const themeId = results.records[0].Id;
        this.ux.startSpinner(`found matching theme with Id ${themeId}...starting headless browser`);
        const browser = await puppeteer.launch({ headless: !this.flags.showbrowser, args: ['--no-sandbox'] });
        const context = browser.defaultBrowserContext();
        // get the force-org-open url for your scratch org
        const openResult = await exec('sfdx force:org:open -p /lightning/setup/ThemingAndBranding/home -r --json');
        const url = JSON.parse(stripcolor(openResult.stdout)).result.url;
        await context.overridePermissions(url, ['notifications']);
        const page = await browser.newPage();
        await page.goto(url, {
            waitUntil: 'networkidle2'
        });
        await page.waitForSelector(`tr[data-row-key-value='${themeId}'`, { visible: true });
        // open up the dropdown menu to populate the Activate link
        await page.evaluate(localThemeId => {
            const button = document.querySelector(`tr[data-row-key-value='${localThemeId}'] td button`);
            return button.click();
        }, themeId);
        // actually activate the theme
        await page.evaluate(localThemeId => {
            const link = Array.from(document.querySelectorAll(`tr[data-row-key-value='${localThemeId}'] td:last-of-type a`))
                .filter(a => a.querySelector('span').innerHTML === 'Activate')[0];
            link.click();
        }, themeId);
        await browser.close();
        this.ux.stopSpinner(`Activated theme ${this.flags.name}`);
        return true;
    }
}
ThemeActivate.description = 'Activate a LightningExperienceTheme via Puppeteer/Chromium headless.  Recommended: use shane:org:reuath -r to make darn sure that the domain is ready to open something';
ThemeActivate.requiresUsername = true;
ThemeActivate.flagsConfig = {
    name: command_1.flags.string({ char: 'n', required: true, description: 'name of the theme to activate' }),
    showbrowser: command_1.flags.boolean({ char: 'b', description: 'show the browser...useful for local debugging' })
};
exports.default = ThemeActivate;
//# sourceMappingURL=activate.js.map