"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const request = require("request-promise-native");
class ObjectInfo extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        this.flags.apiversion = this.flags.apiversion || await conn.retrieveMaxApiVersion();
        const uri = `${conn.instanceUrl}services/data/v${this.flags.apiversion}/ui-api/object-info/${this.flags.object}`;
        const result = await request({
            method: 'get',
            uri,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            json: true
        });
        this.ux.log(result);
        if (this.flags.outputfile) {
            await fs.outputJSON(this.flags.outputfile, result);
        }
        else {
            this.ux.log('you forgot the outputfile');
        }
        return result;
    }
}
ObjectInfo.description = 'get a ui api response from the objectinfo endpoint: https://developer.salesforce.com/docs/atlas.en-us.uiapi.meta/uiapi/ui_api_resources_object_info.htm';
ObjectInfo.examples = [
    `sfdx shane:uiapi:objectinfo -o Account --json
    // returns ui-api objectinfo for Account
    `,
    `sfdx shane:uiapi:objectinfo -o Account --json --outputfile accountObjectInfo.json
    // returns ui-api objectinfo for Account and saves it to a local file
    `
];
ObjectInfo.flagsConfig = {
    object: command_1.flags.string({ char: 'o', description: 'object api name' }),
    outputfile: command_1.flags.filepath({ description: 'local path to save the output to' })
};
// Comment this out if your command does not require an org username
ObjectInfo.requiresUsername = true;
exports.default = ObjectInfo;
//# sourceMappingURL=objectinfo.js.map