"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const request = require("request-promise-native");
class Record extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        this.flags.apiversion = this.flags.apiversion || await conn.retrieveMaxApiVersion();
        let uri = `${conn.instanceUrl}services/data/v${this.flags.apiversion}/ui-api/records/${this.flags.recordid}`;
        if (this.flags.fields) {
            if (uri.includes('?')) {
                uri = `${uri}&fields=${this.flags.fields.join(',')}`;
            }
            else {
                uri = `${uri}?fields=${this.flags.fields.join(',')}`;
            }
        }
        if (this.flags.optionalfields) {
            if (uri.includes('?')) {
                uri = `${uri}&optionalFields=${this.flags.optionalfields.join(',')}`;
            }
            else {
                uri = `${uri}?optionalFields=${this.flags.optionalfields.join(',')}`;
            }
        }
        const result = await request({
            method: 'get',
            uri,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            json: true
        });
        this.ux.log(result);
        if (this.flags.outputfile) {
            await fs.outputJSON(this.flags.outputfile, result);
        }
        return result;
    }
}
Record.description = 'get a ui api response from the getrecord endpoint: https://developer.salesforce.com/docs/atlas.en-us.uiapi.meta/uiapi/ui_api_resources_record_get.htm';
Record.examples = [
    `sfdx shane:uiapi:record -r 001R0000003I6CoIAK -f Account.Name --optionalfields Account.AnnualRevenue,AccountAccount.Number --json
// default ui-api response for a getrecord.
`
];
Record.flagsConfig = {
    recordid: command_1.flags.string({ char: 'r', description: 'single recordId to generate the data/metadata', required: true }),
    fields: command_1.flags.array({ char: 'f', required: true, description: 'fields to return.  Specify with the object API name, like Account.Name, Account.Phone, etc.  If not visible to the running user, an error is thrown' }),
    optionalfields: command_1.flags.array({ description: 'optional fields to return.  If not visible to the running user, the field is just omitted' }),
    outputfile: command_1.flags.filepath({ description: 'local path to save the output to' })
};
// Comment this out if your command does not require an org username
Record.requiresUsername = true;
exports.default = Record;
//# sourceMappingURL=record.js.map