"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const request = require("request-promise-native");
class RecordUI extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        this.flags.apiversion = this.flags.apiversion || await conn.retrieveMaxApiVersion();
        let uri = `${conn.instanceUrl}services/data/v${this.flags.apiversion}/ui-api/record-ui`;
        if (this.flags.recordid) {
            uri = `${uri}/${this.flags.recordid}`;
        }
        else if (this.flags.recordids) {
            uri = `${uri}/${this.flags.recordids.join(',')}`;
        }
        if (this.flags.layouttypes) {
            if (uri.includes('?')) {
                uri = `${uri}&layoutTypes=${this.flags.layouttypes.join(',')}`;
            }
            else {
                uri = `${uri}?layoutTypes=${this.flags.layouttypes.join(',')}`;
            }
        }
        if (this.flags.modes) {
            if (uri.includes('?')) {
                uri = `${uri}&modes=${this.flags.modes.join(',')}`;
            }
            else {
                uri = `${uri}?modes=${this.flags.modes.join(',')}`;
            }
        }
        const result = await request({
            method: 'get',
            uri,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            json: true
        });
        this.ux.log(result);
        if (this.flags.outputfile) {
            await fs.outputJSON(this.flags.outputfile, result);
        }
        return result;
    }
}
RecordUI.description = 'get a ui api response from the record-ui endpoint: https://developer.salesforce.com/docs/atlas.en-us.uiapi.meta/uiapi/ui_api_resources_record_ui.htm';
RecordUI.examples = [
    `sfdx shane:uiapi:recordui -r 001R0000003I6CoIAK --json
// default ui-api response for a single recordId
`
];
RecordUI.flagsConfig = {
    recordid: command_1.flags.string({ char: 'r', description: 'single recordId to generate the data/metadata', exclusive: ['recordids'] }),
    recordids: command_1.flags.array({ description: 'array of recordIds to generate the data/metadata', exclusive: ['recordid'] }),
    layouttypes: command_1.flags.array({
        char: 'l',
        // options: ['Compact', 'Full'],
        description: 'which layout (Compact, Full or both)'
    }),
    modes: command_1.flags.array({
        char: 'm',
        // options: ['Create', 'Edit', 'View'],
        description: 'which mode (Create, Edit, View, or combo)'
    }),
    outputfile: command_1.flags.filepath({ description: 'local path to save the output to' })
};
// Comment this out if your command does not require an org username
RecordUI.requiresUsername = true;
exports.default = RecordUI;
//# sourceMappingURL=recordui.js.map