"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const child_process = require("child_process");
const fs = require("fs-extra");
const request = require("request-promise-native");
const url_1 = require("url");
const util = require("util");
const localFile2CV = require("../../../shared/localFile2CV");
const exec = util.promisify(child_process.exec);
const chalk_1 = require("chalk");
const tempRepo = 'tempRepo';
const photoRepo = 'https://github.com/mshanemc/badProfilePhotos';
class AllPhotos extends command_1.SfdxCommand {
    async run() {
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        let users;
        try {
            users = await conn.query('select id, FirstName, LastName, FullPhotoUrl from user where fullPhotoUrl like \'%/profilephoto/005/F%\'');
        }
        catch (e) {
            this.ux.error(chalk_1.default.red(e));
            throw new Error(e);
        }
        let photos;
        let folderPath;
        // get our bad profile photos
        if (this.flags.folder) {
            folderPath = this.flags.folder;
        }
        else {
            folderPath = `${tempRepo}/img`;
            await exec(`git clone ${this.flags.repo} ${tempRepo}`);
        }
        photos = await fs.readdir(folderPath);
        const options = {
            method: 'POST',
            json: true,
            body: {},
            uri: '',
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            }
        };
        users.records.forEach(async (user, index) => {
            this.ux.log(`going to upload ${photos[index % photos.length]} for ${user.FirstName} ${user.LastName}`);
            const photoCV = await localFile2CV.file2CV(conn, `${folderPath}/${photos[index % photos.length]}`);
            options.uri = `${conn.instanceUrl}/services/data/v42.0/connect/user-profiles/${user.Id}/photo`;
            options.body = {
                fileId: photoCV.ContentDocumentId
            };
            const photoResult = await request(options);
            this.ux.logJson(photoResult);
        });
        await fs.remove(tempRepo);
    }
}
AllPhotos.description = 'set the chatter photos of anyone who has not set theirs already to encourage them to do so';
AllPhotos.examples = [
    'sfdx shane:user:allphotos -u someAlias'
];
AllPhotos.flagsConfig = {
    repo: command_1.flags.url({ char: 'r', default: new url_1.URL(photoRepo), description: 'optional alternate repo of photos, which contains a folder of photos named /img' }),
    folder: command_1.flags.directory({ char: 'f', description: 'optional local folder of photos.  Overrides --repo' })
};
AllPhotos.requiresUsername = true;
AllPhotos.requiresProject = false;
exports.default = AllPhotos;
//# sourceMappingURL=allPhotos.js.map