"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const userIdLookup = require("../../../../shared/userIdLookup");
class UserLightningDebug extends command_1.SfdxCommand {
    async run() {
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        let userId;
        if (this.flags.lastname && this.flags.firstname) {
            const user = await userIdLookup.getUserId(conn, this.flags.lastname, this.flags.firstname);
            userId = user.Id;
        }
        else {
            const users = await conn.query(`select id from user where username = '${this.org.getUsername()}'`);
            userId = users.records[0].Id;
        }
        const updateResult = await conn.sobject('User').update({
            Id: userId,
            UserPreferencesUserDebugModePref: true
        });
        this.ux.log(`added lightning debug mode on user ${userId}`);
        return updateResult;
    }
}
UserLightningDebug.description = 'set the user to debug mode';
UserLightningDebug.examples = [
    `sfdx shane:user:lightning:debug
    // puts the default user in lightning debug mode
    `,
    `sfdx shane:user:lightning:debug -g Sarah -l McLaughlin
    // puts the named user in lightning debug mode
    `
];
UserLightningDebug.flagsConfig = {
    firstname: command_1.flags.string({ char: 'g', description: 'first (given) name of the user--keeping -f for file for consistency' }),
    lastname: command_1.flags.string({ char: 'l', description: 'last name of the user' })
};
UserLightningDebug.requiresUsername = true;
exports.default = UserLightningDebug;
//# sourceMappingURL=debug.js.map