"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const request = require("request-promise-native");
const userIdLookup = require("../../../../shared/userIdLookup");
const chalk_1 = require("chalk");
class Set extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        let user;
        try {
            user = await userIdLookup.getUserId(conn, this.flags.lastname, this.flags.firstname);
        }
        catch (e) {
            throw new Error(e);
        }
        this.ux.log(`found user with id ${user.Id}`);
        const resetResult = await request({
            method: 'post',
            uri: `${conn.instanceUrl}/services/data/v41.0/sobjects/User/${user.Id}/password`,
            body: {
                NewPassword: this.flags.password
            },
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            json: true,
            resolveWithFullResponse: true
        });
        if (resetResult.statusCode !== 204) {
            throw new Error(`Password not set correctly: ${resetResult}`);
        }
        // store in local sfdx
        // await userOrg.saveConfig(Object.assign(orgConfig, { password: pwd }), undefined);
        const auth = await this.org.readUserAuthFiles();
        await auth[0].save(Object.assign({}, auth, { password: this.flags.password }));
        this.ux.log(chalk_1.default.green(`Successfully set the password "${this.flags.password}" for user ${user.Username}.`));
        this.ux.log(`You can see the password again by running "sfdx force:user:display -u ${user.Username}".`);
        return {
            password: this.flags.password,
            username: user.Username
        };
    }
}
Set.description = 'Set the password for a user by first/last name';
Set.examples = [
    `sfdx shane:user:password:set -p sfdx1234 -g User -l User
// sets the password for User User to sfdx1234
`
];
Set.flagsConfig = {
    firstname: command_1.flags.string({ char: 'g', required: true, description: 'first (given) name of the user--keeping -f for file for consistency' }),
    lastname: command_1.flags.string({ char: 'l', required: true, description: 'last name of the user' }),
    password: command_1.flags.string({ char: 'p', required: true, description: 'local path of the photo to use' })
};
// Comment this out if your command does not require an org username
Set.requiresUsername = true;
exports.default = Set;
//# sourceMappingURL=set.js.map