"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const userIdLookup = require("../../../shared/userIdLookup");
class PSLAssign extends command_1.SfdxCommand {
    async run() {
        // const name = this.flags.name || 'world';
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        // const query = 'Select Name, TrialExpirationDate from Organization';
        let user;
        try {
            user = await userIdLookup.getUserId(conn, this.flags.lastname, this.flags.firstname);
        }
        catch (e) {
            this.ux.error(chalk_1.default.red(e));
            throw new Error(e);
        }
        this.ux.log(`found user with id ${user.Id}`);
        const PSLs = await conn.query(`select Id, DeveloperName, MasterLabel from PermissionSetLicense where DeveloperName = '${this.flags.name}' or MasterLabel = '${this.flags.name}'`);
        if (PSLs.totalSize > 1) {
            throw new Error('There are more than 1 result for that name.');
        }
        else if (PSLs.totalSize === 0) {
            throw new Error('PSL not found');
        }
        else {
            this.ux.log(`found PSL with id ${PSLs.records[0].Id}`);
        }
        const createResult = await conn.create('PermissionSetLicenseAssign', {
            AssigneeId: user.Id,
            PermissionSetLicenseId: PSLs.records[0].Id
        });
        this.ux.logJson(createResult);
        return createResult;
    }
}
PSLAssign.description = 'Assign a permset license already in an org for a user';
PSLAssign.examples = [
    `sfdx shane:user:psl -n SomePSL -g User -l User
// assign the PSL named 'somePSL' for the user named User User
`
];
PSLAssign.flagsConfig = {
    firstname: command_1.flags.string({ char: 'g', description: 'first (given) name of the user--keeping -f for file for consistency' }),
    lastname: command_1.flags.string({ char: 'l', required: true, description: 'last name of the user' }),
    name: command_1.flags.filepath({ char: 'n', required: true, description: 'developer name or label of the PermSetLicense' })
};
// Comment this out if your command does not require an org username
PSLAssign.requiresUsername = true;
// Comment this out if your command does not support a hub org username
// protected static supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
PSLAssign.requiresProject = false;
exports.default = PSLAssign;
//# sourceMappingURL=psl.js.map